@@ -1,12 +1,12 @@
 bc.data.frame <-
 function(x, n_cat, stack100,
          col_fill, col_color, col.trans, fill_spit, theme,
-         horiz, gap, prop, scale_y, top,
+         horiz, gap, prop, scale_y, 
          xlab, ylab, main,
-         labels, label.size, beside,
+         value_labels, label.size, beside,
          rotate_x, offset, break_x, sort_x,
-         values, values_color, values_cex, value.digits,
-         values_position, values_cut,
+         labels, labels_color, labels_cex, labels_digits,
+         labels_position, labels_cut,
          xlab_adj, ylab_adj, bm.adj, lm.adj, tm.adj, rm.adj,
          pad_y_min, pad_y_max,
          legend_title, legend_position, legend_labels,
@@ -65,12 +65,12 @@ function(x, n_cat, stack100,
 
         .bc.main(x[,i], y=NULL, by=NULL, stack100,
           col_fill, col_color, col.trans, fill_spit, theme,
-          horiz, gap, prop, scale_y, top,
+          horiz, gap, prop, scale_y, 
           xlab, ylab, main,
           value_labels=NULL, label.size, beside,
           rotate_x, offset, break_x, sort_x,
-          values, values_color, values_cex, value.digits,
-          values_position, values_cut,
+          labels, labels_color, labels_cex, labels_digits,
+          labels_position, labels_cut,
           xlab_adj, ylab_adj, bm.adj, lm.adj, tm.adj, rm.adj,
           pad_y_min, pad_y_max,
           legend_title, legend_position, legend_labels,
