@@ -13,7 +13,7 @@ function (R=mycor, order=c("hclust", "chain", "manual", "as_is"),
   dots <- list(...)
   if (!is.null(dots)) if (length(dots) > 0) {
     for (i in 1:length(dots)) {
-      if (names(dots)[i] == "values.cex")  values_size <- dots[[i]]
+      if (names(dots)[i] == "values.cex")  labels_size <- dots[[i]]
       if (grepl(".", names(dots)[i], fixed=TRUE)) {
         nm <- gsub(".", "_", names(dots)[i], fixed=TRUE)
         assign(nm, dots[[i]])
