@@ -25,14 +25,14 @@ function(mylevels, color, fill, shp, trans_pts, col.bg, usr,
   ll <- legend(0,0, legend=legend_labels, title=legend_title, cex=.7,
                pt.cex=pt.size, pt.lwd=pt.lwd, plot=FALSE)
 
-  size <- (par("cxy")/par("cin"))  # 1 inch in user coordinates 
+  size <- (par("cxy")/par("cin"))  # 1 inch in user coordinates
 
   epsilon <- (size[1] - ll$rect$w) / 2
   if (epsilon < 0) epsilon <- .04  # do not have label overlap plot
 
   axis_vert <- usr[4] - usr[3]
   xleft <- usr[2] + epsilon - .01 # usr[2] user coordinate of right axis
-  if (mx.ch > 7) xleft <- xleft - .02  # shift legend left a bit   
+  if (mx.ch > 7) xleft <- xleft - .02  # shift legend left a bit
   lgnd.vhalf <- (ll$rect$h) / 2
   axis_cntr <- axis_vert / 2  + usr[3]
   ytop <- axis_cntr + lgnd.vhalf  # user coordinate of legend top
@@ -41,7 +41,7 @@ function(mylevels, color, fill, shp, trans_pts, col.bg, usr,
     legend_fill <- integer(length=n.levels)
     for (i in 1:n.levels) legend_fill[i] <- .maketrans(color[i],.7)
   }
-  else 
+  else
     legend_fill <- fill
 
   the.clr <- getOption("lab_color")
@@ -49,7 +49,7 @@ function(mylevels, color, fill, shp, trans_pts, col.bg, usr,
   yi <- 0.95
 
   if (is.null(legend_size)) {
-    axis_x_cex <- ifelse(is.null(getOption("axis_x_cex")), 
+    axis_x_cex <- ifelse(is.null(getOption("axis_x_cex")),
       getOption("axis_cex"), getOption("axis_x_cex"))
     adj <- .RSadj(axis_cex=axis_x_cex); axis_x_cex <- adj$axis_cex
     legend_size <- axis_x_cex
@@ -59,10 +59,19 @@ function(mylevels, color, fill, shp, trans_pts, col.bg, usr,
   # fill=length(legend_labels):1  puts the legend labels in the correct
   #   order, but only for inflexible boxes that cannot be resized with pt.cex
   if (pt.size == 0) pt.size <- 1.2
-  legend(xleft+legend_adj, ytop, legend=legend_labels, title=legend_title, 
-         pch=shp, horiz=FALSE, cex=legend_size, pt.cex=pt.size, pt.lwd=pt.lwd,
-         bg=col.bg, col=color, pt.bg=fill,
-         text.col=the.clr, y.intersp=yi, bty="n")
+  if (shp != "lines")
+    legend(xleft+legend_adj, ytop, legend=legend_labels, title=legend_title,
+           pch=shp, horiz=FALSE, cex=legend_size, pt.cex=pt.size, pt.lwd=pt.lwd,
+           bg=col.bg, col=color, pt.bg=fill,
+           text.col=the.clr, y.intersp=yi, bty="n")
+  else {  # for plotting data and forecast
+    xleft <- usr[2] + epsilon/4
+    legend(xleft+legend_adj, ytop, legend=legend_labels, title=legend_title,
+           cex=legend_size, pt.cex=pt.size, pt.lwd=pt.lwd,
+           bg=col.bg, col=color, pt.bg=fill,
+           text.col=the.clr, bty="n",
+           lty=c("solid", "solid", "solid"), lwd=c(2,2,2), y.intersp=1.6)
+    }
 
   par(xpd=FALSE)  # cancel drawing outside of plot region (need for RStudio)
 
